Learn R Programming

syuzhet (version 1.0.0)

get_stanford_sentiment: Get Sentiment from the Stanford Tagger

Description

Call the Stanford Sentiment tagger with a vector of strings. The Stanford tagger automatically detects sentence boundaries and treats each sentence as a distinct instance to measure. As a result, the vector that gets returned will not be the same length as the input vector.

Usage

get_stanford_sentiment(text_vector, path_to_stanford_tagger)

Arguments

text_vector
A vector of strings
path_to_stanford_tagger
a local file path indicating where the coreNLP package is installed.