get_nrc_values: Summarize NRC Values
Description
Access the NRC dictionary to compute emotion types and
valence for a set of words in the input vector.
Usage
get_nrc_values(word_vector)
Arguments
word_vector
A character vector.
Value
A vector of values for the emotions and valence
detected in the input vector.