get_stanford_sentiment: Get Sentiment from the Stanford Tagger
Description
Call the Stanford Sentiment tagger with a
vector of strings. The Stanford tagger automatically
detects sentence boundaries and treats each sentence as a
distinct instance to measure. As a result, the vector
that gets returned will not be the same length as the
input vector.